@@ -12,9 +12,9 @@
 
 #' Extract monthly flows information from the HYDAT database
 #'
-#' Tidy data of monthly flows information from the monthly_flows HYDAT table. \code{station_number} and
-#' \code{prov_terr_state_loc} can both be supplied. If both are omitted all values from the \code{hy_stations} table are returned.
-#' That is a large vector for \code{hy_monthly_flows}.
+#' Tidy data of monthly flows information from the monthly_flows HYDAT table. `station_number` and
+#' `prov_terr_state_loc` can both be supplied. If both are omitted all values from the `hy_stations` table are returned.
+#' That is a large vector for `hy_monthly_flows`.
 #'
 #' @inheritParams hy_stations
 #' @param start_date Leave blank if all dates are required. Date format needs to be in YYYY-MM-DD. Date is inclusive.
@@ -61,7 +61,7 @@ hy_monthly_flows <- function(station_number = NULL,
   ## Read in database
   hydat_con <- hy_src(hydat_path)
   if (!dplyr::is.src(hydat_path)) {
-    on.exit(hy_src_disconnect(hydat_con))
+    on.exit(hy_src_disconnect(hydat_con), add = TRUE)
   }
 
   ## Determine which stations we are querying
